==> mvnmeta-0.1.5-20140418.144002-2.jar: project.clj <==
(defproject org.ozias.cljlibs/mvnmeta "0.1.5-SNAPSHOT"
  :description "Fetch maven artifact metadata into a Clojure map"
  :url "https://github.com/CraZySacX/mvnmeta"
  :license {:name "MIT"
            :url "http://opensource.org/licenses/MIT"}
  :dependencies [[clj-http "0.9.1"]
                 [org.clojure/clojure "1.6.0"]
                 [org.clojure/data.xml "0.0.7"]]
  :profiles {:dev {:source-paths ["dev"]
                   :dependencies [[org.clojars.jozias/midje "1.6.3"
                                   :exclusions [org.clojure/clojure]]
                                  [org.clojure/tools.namespace "0.2.4"]]
                   :plugins [[codox "0.6.7"]
                             [lein-midje "3.1.3"]
                             [org.ozias.plugins/lein-git-version "1.1.2"]]
                   :aliases {"package" ["do" "clean," "install"]
                             "slamhound" ["run" "-m" "slam.hound"]
                             "chk" ["do" "slamhound," "eastwood"
                                    "{:namespaces [:source-paths]}," "kibit,"
                                    "bikeshed," "check," "archaic" "upgrade"]
                             "most" ["do" "clean," "doc," "chk," "package"]
                             "dep" ["do" "deploy," "deploy" "clojars"]
                             "all" ["do" "most," "dep"]}}}
  :jvm-opts ["-Xms1024m" "-Xmx1024m"]
  :deploy-repositories [["snapshots" 
                         {:url
                          "http://www.ozias.net/artifactory/libs-snapshot-local"
                          :creds :gpg}]
                        ["releases"
                         {:url
                          "http://www.ozias.net/artifactory/libs-release-local"
                          :creds :gpg}]]
  :scm {:name "git"
        :url "https://github.com/CraZySacX/mvnmeta"}
  :codox {:output-dir "api"
          :exclude [org.ozias.cljlibs.mvnmeta.version]
          :sources ["src" "test"]
          :src-dir-uri "http://github.com/CraZySacX/mvnmeta/blob/master/"
          :src-linenum-anchor-prefix "L"}
  :manifest {"Implementation-Version" "0.1.5-SNAPSHOT"}
  :git-version {:file {:assoc-in-keys [[:manifest "Implementation-Version"]]}})

==> mvnmeta-0.1.7-20140502.181709-1.jar: project.clj <==
(defproject org.ozias.cljlibs/mvnmeta "0.1.7-SNAPSHOT"
  :description "Fetch maven artifact metadata into a Clojure map"
  :url "https://github.com/CraZySacX/mvnmeta"
  :license {:name "MIT"
            :url "http://opensource.org/licenses/MIT"}
  :dependencies [[clj-http "0.9.1"]
                 [org.clojure/clojure "1.6.0"]
                 [org.clojure/data.xml "0.0.7"]]
  :profiles {:dev {:source-paths ["dev"]
                   :dependencies [[org.clojars.jozias/midje "1.6.3"
                                   :exclusions [org.clojure/clojure]]
                                  [org.clojure/tools.namespace "0.2.4"]
                                  [org.ozias.cljlibs/scm "0.1.3"]]
                   :plugins [[codox "0.6.8"]
                             [lein-midje "3.1.3"]
                             [org.ozias.plugins/lein-git-version "1.1.3"]]
                   :aliases {"package" ["do" "clean," "install"]
                             "slamhound" ["run" "-m" "slam.hound"]
                             "chk" ["do"
                                    "archaic" "upgrade,"
                                    "slamhound" "src/,"
                                    "slamhound" "test/,"
                                    "eastwood"
                                    "{:namespaces [:source-paths] :exclude-linters [:unused-ret-vals]},"
                                    "kibit,"
                                    "bikeshed" "-v,"
                                    "check,"
                                    "midje"]
                             "most" ["do" "clean," "doc," "chk," "package"]
                             "dep" ["do" "deploy," "deploy" "clojars"]
                             "all" ["do" "most," "dep"]}}}
  :jvm-opts ["-Xms1024m" "-Xmx1024m"]
  :deploy-repositories [["snapshots" 
                         {:url
                          "http://www.ozias.net/artifactory/libs-snapshot-local"
                          :creds :gpg}]
                        ["releases"
                         {:url
                          "http://www.ozias.net/artifactory/libs-release-local"
                          :creds :gpg}]]
  :scm {:name "git"
        :url "https://github.com/CraZySacX/mvnmeta"}
  :codox {:output-dir "api"
          :exclude [org.ozias.cljlibs.mvnmeta.version]
          :src-dir-uri "http://github.com/CraZySacX/mvnmeta/blob/master/"
          :src-linenum-anchor-prefix "L"}
  :manifest {"Implementation-Version" "0.1.7-SNAPSHOT"}
  :git-version {:file {:assoc-in-keys [[:manifest "Implementation-Version"]]}})
